# Intermediate BO4E M**I**gration Models (ibims)

![Unittests status badge](https://github.com/Hochfrequenz/bo4e-migration-model/workflows/Unittests/badge.svg)
![Coverage status badge](https://github.com/Hochfrequenz/bo4e-migration-model/workflows/Coverage/badge.svg)
![Linting status badge](https://github.com/Hochfrequenz/bo4e-migration-model/workflows/Linting/badge.svg)
![Black status badge](https://github.com/Hochfrequenz/bo4e-migration-model/workflows/Formatting/badge.svg)

A data model for migrating data from one system to another.
The package name is "ibims".

### Installation

It's also [available on pypi](https://pypi.org/project/ibims/).
```bash
pip install ibims
```

### Documentation
There is a (very early stage) documentation of this repository on [readthedocs](https://intermediate-bo4e-migration-models.readthedocs.io/de/latest/api/ibims.html).

## How to use this Repository on Your Machine

Follow the instructions in our [Python template repository](https://github.com/Hochfrequenz/python_template_repository#how-to-use-this-repository-on-your-machine).

## Contribute

You are very welcome to contribute to this template repository by opening a pull request against the main branch.
